"""
NX100 robot connection parameters
"""
NX100_IP_ADDRESS = "192.168.2.28"
NX100_TCP_PORT = 80

"""
When True, will return mock responses so no real robot is required
mostly used to run tests
"""
MOCK_RESPONSE = False
